'use strict';

exports.__esModule = true;

var _util = require('../utils/util.js');

exports.default = {
    data: function data() {
        return {
            dom: '',

            width: 0,
            height: 0,

            debounceInitWHFun: '',

            domObserver: ''
        };
    },

    methods: {
        autoResizeMixinInit: function autoResizeMixinInit() {
            var initWH = this.initWH,
                getDebounceInitWHFun = this.getDebounceInitWHFun,
                bindDomResizeCallback = this.bindDomResizeCallback,
                afterAutoResizeMixinInit = this.afterAutoResizeMixinInit;


            initWH(false).then(function () {
                getDebounceInitWHFun();

                bindDomResizeCallback();

                if (typeof afterAutoResizeMixinInit === 'function') afterAutoResizeMixinInit();
            });
        },
        initWH: function initWH() {
            var _this = this;

            var resize = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;
            var $nextTick = this.$nextTick,
                $refs = this.$refs,
                ref = this.ref,
                onResize = this.onResize;


            return new Promise(function (resolve) {
                $nextTick(function (_) {
                    var dom = _this.dom = $refs[ref];

                    _this.width = dom ? dom.clientWidth : 0;
                    _this.height = dom ? dom.clientHeight : 0;

                    if (!dom) {
                        console.warn('iCityUI: Failed to get dom node, component rendering may be abnormal!');
                    } else if (!_this.width || !_this.height) {
                        console.warn('iCityUI: Component width or height is 0px, rendering abnormality may occur!');
                    }

                    if (typeof onResize === 'function' && resize) onResize();

                    resolve();
                });
            });
        },
        getDebounceInitWHFun: function getDebounceInitWHFun() {
            var initWH = this.initWH;


            this.debounceInitWHFun = (0, _util.debounce)(100, initWH);
        },
        bindDomResizeCallback: function bindDomResizeCallback() {
            var dom = this.dom,
                debounceInitWHFun = this.debounceInitWHFun;


            this.domObserver = (0, _util.observerDomResize)(dom, debounceInitWHFun);

            window.addEventListener('resize', debounceInitWHFun);
        },
        unbindDomResizeCallback: function unbindDomResizeCallback() {
            var domObserver = this.domObserver,
                debounceInitWHFun = this.debounceInitWHFun;


            if (!domObserver) return;

            domObserver.disconnect();
            domObserver.takeRecords();
            domObserver = null;

            window.removeEventListener('resize', debounceInitWHFun);
        }
    },
    mounted: function mounted() {
        var autoResizeMixinInit = this.autoResizeMixinInit;


        autoResizeMixinInit();
    },
    beforeDestroy: function beforeDestroy() {
        var unbindDomResizeCallback = this.unbindDomResizeCallback;


        unbindDomResizeCallback();
    }
};